import { Button, TableBody } from "@mui/material";
import { TableRow, TableCell } from "@mui/material";
import { Table, TableHead } from "@mui/material";
import { mediaStore, MEDIA_TYPE_LABELS } from "@shared";
import { useEffect } from "react";
import { observer } from "mobx-react-lite";
import { Eye, Pencil, Trash2 } from "lucide-react";
import { useNavigate } from "react-router-dom";

const rows = (media: any[]) => {
  return media.map((row) => ({
    id: row.id,
    media_name: row.media_name,
    media_type:
      MEDIA_TYPE_LABELS[row.media_type as keyof typeof MEDIA_TYPE_LABELS],
  }));
};

export const MediaListPage = observer(() => {
  const { media, getMedia, deleteMedia } = mediaStore;
  const navigate = useNavigate();
  useEffect(() => {
    getMedia();
  }, []);

  const currentRows = rows(media);

  return (
    <>
      <div className="flex justify-end p-3 gap-5">
        <Button
          variant="contained"
          color="primary"
          onClick={() => navigate("/sight/create")}
        >
          Создать
        </Button>
      </div>
      <Table sx={{ minWidth: 650 }} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell align="center">Название</TableCell>
            <TableCell align="center">Тип</TableCell>
            <TableCell align="center">Действия</TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {currentRows.map((row) => (
            <TableRow
              key={row.media_name}
              sx={{ "&:last-child td, &:last-child th": { border: 0 } }}
            >
              <TableCell align="center">{row.media_name}</TableCell>
              <TableCell align="center">{row.media_type}</TableCell>
              <TableCell align="center">
                <div className="flex gap-7 justify-center">
                  <button onClick={() => navigate(`/media/${row.id}`)}>
                    <Eye size={20} className="text-green-500" />
                  </button>

                  <button onClick={() => navigate(`/media/${row.id}/edit`)}>
                    <Pencil size={20} className="text-blue-500" />
                  </button>

                  <button onClick={() => deleteMedia(row.id)}>
                    <Trash2 size={20} className="text-red-500" />
                  </button>
                </div>
              </TableCell>
            </TableRow>
          ))}
        </TableBody>
      </Table>
    </>
  );
});
